/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.admin.controller;

import se.vgregion.portal.cs.domain.SiteKey;
import se.vgregion.portal.cs.domain.UserSiteCredential;

import java.io.Serializable;
import java.util.*;

public class UserSiteCredentialHelper {
    private final List<UserSiteCredential> userSiteCredentials;

    public UserSiteCredentialHelper(List<UserSiteCredential> value) {
        this.userSiteCredentials = value;
    }

    public UserSiteCredentialHelper(Collection<UserSiteCredential> value) {
        this(new ArrayList<UserSiteCredential>(value));
    }

    public List<UserSiteCredential> get() {
        return userSiteCredentials;
    }

    public UserSiteCredentialHelper orderBySiteKey() {
        Collections.sort(userSiteCredentials, new UserSiteCredentialComparator());
        return new UserSiteCredentialHelper(userSiteCredentials);
    }

    private static class UserSiteCredentialComparator implements Comparator<UserSiteCredential>, Serializable {
        private static final long serialVersionUID = 9051962582752211347L;

        @Override
        public int compare(UserSiteCredential one, UserSiteCredential other) {
            return one.getSiteKey().compareTo(other.getSiteKey());
        }
    }

    public UserSiteCredentialHelper filterValid() {
        for (Iterator<UserSiteCredential> it = userSiteCredentials.iterator(); it.hasNext();) {
            UserSiteCredential siteKey = it.next();
            if (!siteKey.isValid()) it.remove();
        }
        return new UserSiteCredentialHelper(userSiteCredentials);
    }

}
